<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
    append-to-body
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="80px"
      class="l-mes"
    >
      <el-form-item label="退货数量" prop="sendBackQuantity">
        <el-input
          v-model="dataForm.sendBackQuantity"
          placeholder="退货数量"
        ></el-input>
      </el-form-item>
      <el-form-item label="退货日期" prop="sendBackDate">
        <el-date-picker
          style="width: 100%"
          v-model="dataForm.sendBackDate"
          type="date"
          placeholder="选择日期"
          value-format="yyyy-MM-dd HH:mm:ss"
        >
        </el-date-picker>
      </el-form-item>
      <el-form-item label="是否退回公司" prop="isCompany">
        <el-input
          v-model="dataForm.isCompany"
          placeholder="是否退回公司"
        ></el-input>
      </el-form-item>
      <el-form-item label="退回公司日期" prop="sendBackCompanyDate">
        <el-date-picker
          style="width: 100%"
          v-model="dataForm.sendBackCompanyDate"
          type="date"
          placeholder="选择日期"
          value-format="yyyy-MM-dd HH:mm:ss"
        >
        </el-date-picker>
      </el-form-item>
      <el-form-item label="退货原因" prop="sendBackReason">
        <el-input
          v-model="dataForm.sendBackReason"
          placeholder="退货原因"
        ></el-input>
      </el-form-item>
      <el-form-item label="退货库位" prop="sendBackLocationId">
        <el-input
          v-model="dataForm.sendBackLocationName"
          placeholder="退货库位"
          readonly
        >
          <el-button
            slot="append"
            icon="el-icon-search"
            @click="openSelectBackLocation"
          ></el-button>
        </el-input>
      </el-form-item>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>

    <locationDialog
      :currshowlist.sync="showBackLocation"
      @listenToLocationEvent="selectBackLocation"
    />
  </el-dialog>
</template>

<script>
import {
  getObj,
  addObj,
  putObj,
  getDeaultLocation
} from '@/api/warehouse/sendback'
import locationDialog from '@/views/common/location.vue'

export default {
  props: {
    sendBackList: {
      type: Array,
      default: []
    }
  },

  data() {
    return {
      deaultLocation: {},
      showBackLocation: false,
      showEscort: false,
      visible: false,
      dataForm: {
        id: 0,
        escortDetailId: '',
        partNo: '',
        partName: '',
        partBatchNo: '',
        systemNo: '',
        sendBackQuantity: '',
        partUnit: '',
        sendBackDate: '',
        isCompany: '',
        sendBackCompanyDate: '',
        sendBackReason: '',
        sendBackLocationId: '',
        sendBackLocationName: '',
        escortList: []
      },
      dataRule: {
        sendBackQuantity: [
          { required: true, message: '退货数量不能为空', trigger: 'blur' }
        ]
      },
      isSubmit: false
    }
  },
  components: {
    locationDialog
  },
  methods: {
    selectBackLocation(param) {
      if (typeof param !== 'undefined') {
        this.dataForm.sendBackLocationId = param.id
        this.dataForm.sendBackLocationName = param.locName
      }
    },

    openSelectBackLocation() {
      this.showBackLocation = true
    },
    init(param) {
      this.dataForm.escortList = []
      this.dataForm.escortList = param
      this.visible = true
      var sendBackQuantity = -Object.is(param[0].sendBackQuantity, NaN)
        ? 0
        : param[0].sendBackQuantity
      this.dataForm.sendBackQuantity =
        Number(param[0].deliveryQty) - sendBackQuantity
      this.fillDeaultLocation()
    },
    fillDeaultLocation() {
      getDeaultLocation().then((res) => {
        this.deaultLocation = res.data
        if (this.deaultLocation) {
          this.dataForm.sendBackLocationId = this.deaultLocation.id
          this.dataForm.sendBackLocationName = this.deaultLocation.locName
        }
      })
    },
    getSendBack(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (!this.dataForm.sendBackQuantity) {
            this.$message.error('此条记录已退货,可退货数量为0')
            this.visible = false
            this.isSubmit = false
            return
          }
          if (this.dataForm.id) {
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            addObj(this.dataForm).then((data) => {
              this.$message.success('退货成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
